@@ -1,7 +1,7 @@
 use super::status::Status;
 
 /// Counts number of tests with a specific result
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct Counter {
     pub num_skip:	u32,
     pub num_todo:	u32,
@@ -35,17 +35,3 @@ impl Counter {
 	    self.num_panic + self.num_abort
     }
 }
-
-impl Default for Counter {
-    fn default() -> Self {
-	Self {
-	    num_skip:		0,
-	    num_todo:		0,
-	    num_pass:		0,
-	    num_degraded:	0,
-	    num_fail:		0,
-	    num_panic:		0,
-	    num_abort:		0,
-	}
-    }
-}
